@@ -3,18 +3,12 @@ import django_tables2 as tables
 from netbox.tables import (
     NetBoxTable,
     ToggleColumn,
-    ActionsColumn,
 )
 
 from netbox_storage.models import Drive
 
 
-class DriveBaseTable(NetBoxTable):
-    """Base class for tables displaying Drives"""
-
-
-
-class DriveTable(DriveBaseTable):
+class DriveTable(NetBoxTable):
     """Table for displaying Drives objects."""
 
     pk = ToggleColumn()
