@@ -1,6 +1,6 @@
 from extras.plugins import PluginTemplateExtension
 
-from netbox_storage.models import Drive
+from netbox_storage.models import Drive, Partition
 
 
 class RelatedDrives(PluginTemplateExtension):
@@ -28,6 +28,11 @@ class RelatedDrives(PluginTemplateExtension):
         # display_volume = []
         # for volume in all_volumes:
         #     display_volume = volume.drives.all().intersection(drives)
+        display_partition = []
+        for drive in drives:
+            display_partition = Partition.objects.filter(
+                drive=drive
+            )
 
         platform = obj.platform
         if platform is not None:
@@ -45,7 +50,7 @@ class RelatedDrives(PluginTemplateExtension):
                 return self.render(
                     "netbox_storage/volume/linuxvolume_box.html",
                     extra_context={
-                        # "related_drives": drive_table,
+                        "partitions": display_partition,
                     },
                 )
         else:
